Adjust the values in the new :file:`settings.py` file to your liking. You can
stick with shipped example for testing purposes, but you will want changes for
production setup, see :ref:`configuration`.
